<div id="top"></div>

<br/>
<div align="center">
  <a href="https://github.com/BornPaster/bruce">
    <img src="https://i.imgur.com/uBjkI1D.png" alt="Logo" >
  </a>
  
  <h2 align="center">Bruce™</h3>

  <p align="center">
    A very sleek, modern, and monochrome style logger modification.
    <br />
    <br />
    <a href="https://github.com/BornPaster/bruce/issues">Report Bug</a>
    ·
    <a href="https://github.com/BornPaster/bruce/issues">Request Feature</a>
  </p>
</div>


---------------------------------------

### Requirements
* Windows OS

---------------------------------------

### Notes
* can be used for anything including tools, api, etc.
* very clean and super sleek so its actually good to look at.
* star the repo if you end up liking what you see <3